pplugins
========
[![Documentation Status](https://readthedocs.org/projects/pplugins/badge/?version=latest)](http://pplugins.readthedocs.org/en/latest/?badge=latest) [![Build Status](https://travis-ci.org/JohnMaguire/pplugins.svg?branch=master)](https://travis-ci.org/JohnMaguire/pplugins) [![Coverage Status](https://coveralls.io/repos/github/JohnMaguire/pplugins/badge.svg?branch=master)](https://coveralls.io/github/JohnMaguire/pplugins?branch=master)

Think of it as the yapsy of multiprocessing.

Supported versions
------------------
* Python 2.7
* Python 3.3+
